MutDom

Struct MutDom 

pub struct MutDom<T: DomObject> { /* private fields */ }
A holder that provides interior mutability for GC-managed values such as Dom<T>. Essentially a Cell<Dom<T>>, but safer.

This should only be used as a field in other DOM objects; see warning on Dom<T>.

Implementations

Source

impl<T: DomObject> MutDom<T>

pub fn new(initial: &T) -> MutDom<T>

Create a new MutDom.

pub fn set(&self, val: &T)

Set this MutDom to the given value.

pub fn get(&self) -> DomRoot<T>

Get the value in this MutDom.

pub fn get_unrooted<'a>(&self, _: &'a NoGC) -> UnrootedDom<'a, T>

Get the DomObject without rooting it as an UnrootedDom. This is safe as the return value shares the lifetime of the provided NoGC This implies that while the UnrootedDom is alive, garbage collection will not happen.

pub unsafe fn as_ref_unsafe(&self) -> &Dom<T>

Get a reference to the traced inner value of this MutDom.

Safety
  • The caller must not modify the value of the MutDom while the reference is alive.
  • The caller must ensure that no garbage collection happens while the reference is alive.