pub unsafe trait LayoutFromRaw<'dom, T: DomObject> {
// Required method
fn from_raw(d: &'dom T) -> Self;
}Expand description
Trait that creates a specific struct from a raw DomObject. The implementer needs to be sure that this does not violate any lifetimes
Safety
The dom object needs the lifetimes to be safe.
Only [LayoutDom] should implement this.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".