Crate script_bindings

Crate script_bindings 

Modules

assert
callback
Base classes to work with IDL callbacks.
cell
A shareable mutable container for the DOM.
codegen
conversions
domstring
error
inheritance
The Castable trait.
interface
Machinery to initialise interface prototype objects and interface objects.
interfaces
iterable
Implementation of iterable<...> and iterable<..., ...> WebIDL declarations.
like
Implementation of setlike<...> and maplike<..., ...> WebIDL declarations.
num
The Finite<T> struct.
principals
proxyhandler
Utilities for the implementation of JSAPI proxy handlers.
realms
record
The Record (open-ended dictionary) type.
reflector
root
script_runtime
settings_stack
str
The ByteString struct.
structuredclone
trace
utils
weakref
Weak-referenceable JS-managed DOM objects.
wrap

Macros

cformat
Creates a CString using interpolation of runtime expressions. Basically a format! that produces a CString.
match_domstring_ascii
Use this to match &str against lazydomstring efficiently. You are only allowed to match ascii strings otherwise this macro will lead to wrong results.
match_domstring_ascii_inner

Traits

DomTypes