Get the property with name property from object.
Returns Err(()) on JSAPI failure (there is a pending exception), and
Ok(false) if there was no property with the given name.
Checks whether object has an own property named property.
Returns Err(()) on JSAPI failure (there is a pending exception),
and Ok(false) for null objects or when the property is not own.